import Vue from 'vue';

// 创建可观察对象
const bankNumberValue = Vue.observable({
  value: ''
});

// 自定义指令：银行账号格式化
Vue.directive('format-bank-number', {
  bind(el, binding) {
    el.addEventListener('input', handleInput);

    function handleInput() {
      const value = el.value.replace(/\s/g, ''); // 去除所有空格
      let formatted = '';
      if (value) {
        formatted = value.match(/.{1,4}/g).join(' '); // 每四位添加一个空格
      }
      el.value = formatted;
      bankNumberValue.value = value; // 更新银行账号的值
      binding.value = value; // 更新表单数据
    }
  },
  unbind(el) {
    el.removeEventListener('input', handleInput);
  }
});