import { login, logout, getInfo, socialLogin, smsLogin } from '@/api/login'
import { setToken, removeToken } from '@/utils/auth'
import { handleAreaLoop } from '@/utils'
import { getAreaTree } from '@/api/system/area'
import { getUserProfile } from "@/api/system/user";
import { listSimpleDepts } from "@/api/system/dept";
import { handleTree } from "@/utils/ruoyi";

const user = {
  state: {
    id: 0, // 用户编号
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    areaTree: [], // 地区信息
    userInfo: {}, // 用户信息
    userDeptTree: {}, //  部门
    newDefaultProps: {
      children: "children",
      label: "name",
      value: 'id',
      emitPath: false,
      checkStrictly: true
    }, // 地区配置
  },

  mutations: {
    SET_ID: (state, id) => {
      state.id = id
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_NICKNAME: (state, nickname) => {
      state.nickname = nickname
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_AREATREE: (state, areaTree) => {
      const result = areaTree.map(item => {
        const children = item.children.map(every => {
          return {
            name: every.name,
            id: every.id
          };
        })
        return {
          ...item,
          children: children
        };
      })
      state.areaTree = result
    },
    SET_USERINFO: (state, userInfo) => {
      state.userInfo = userInfo
    },
    SET_USERDEPTREE: (state, userDeptTree) => {
      state.userDeptTree = userDeptTree
    },
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const captchaVerification = userInfo.captchaVerification
      const socialCode = userInfo.socialCode
      const socialState = userInfo.socialState
      const socialType = userInfo.socialType
      return new Promise((resolve, reject) => {
        login(username, password, captchaVerification, socialType, socialCode, socialState).then(res => {
          console.log(res)
          if(res.result){
            alert(res.result)
          }
          res = res.data;
          // 设置 token
          setToken(res)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 社交登录
    SocialLogin({ commit }, userInfo) {
      const code = userInfo.code
      const state = userInfo.state
      const type = userInfo.type
      return new Promise((resolve, reject) => {
        socialLogin(type, code, state).then(res => {
          res = res.data;
          // 设置 token
          setToken(res)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 短信登录
    SmsLogin({ commit }, userInfo) {
      const mobile = userInfo.mobile.trim()
      const mobileCode = userInfo.mobileCode
      return new Promise((resolve, reject) => {
        smsLogin(mobile, mobileCode).then(res => {
          res = res.data;
          // 设置 token
          setToken(res)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          // 没有 data 数据，赋予个默认值
          if (!res) {
            res = {
              data: {
                roles: [],
                user: {
                  id: '',
                  avatar: '',
                  userName: '',
                  nickname: ''
                }
              }
            }
          }

          res = res.data; // 读取 data 数据
          const user = res.user
          const avatar = (user.avatar === "" || user.avatar == null) ? require("@/assets/images/profile.jpg") : user.avatar;
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          commit('SET_ID', user.id)
          commit('SET_NAME', user.userName)
          commit('SET_NICKNAME', user.nickname)
          getAreaTree().then(res => {
            // console.log('res..', res.data);
            let tree = res.data || []
            handleAreaLoop(tree)
            commit('SET_AREATREE', tree)
          })
          listSimpleDepts().then((res) => {
            let deptOptions = [];
            deptOptions.push(...handleTree(res.data, "id"));
            commit('SET_USERDEPTREE', deptOptions)
          })
          // 获取用户个人信息
          getUserProfile().then((res) => {
            commit('SET_USERINFO', res.data)
            resolve(res)
          })

        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
